# `running-ng`
`running-ng` is a collection of scripts that help people run workloads in a methodologically sound settings.

## Installation
`pip install running-ng`

## Documentation
Please refer to [this site](https://anupli.github.io/running-ng/) for up-to-date documentations.

## License
This project is licensed under the Apache License, Version 2.0.
